@@ -4,12 +4,12 @@ cox.aalen<-function(formula=formula(data),data=sys.parent(),
 beta=0,Nit=10,detail=0,start.time=0,max.time=NULL, id=NULL, 
 clusters=NULL, n.sim=500, residuals=0,robust=1,
 weighted.test=0,covariance=0,resample.iid=0,weights=NULL,
-rate.sim=1,beta.fixed=0)
+rate.sim=1,beta.fixed=0,max.clust=1000)
 {
   ridge<-0; ratesim<-rate.sim; if (n.sim==0) sim<-0 else sim<-1; 
   call <- match.call()
-  m <- match.call(expand=FALSE)
-  m$robust<-m$start.time<-m$scaleLWY<-m$weighted.test<-m$beta<-m$Nit<-m$detail<-m$max.time<-m$residuals<-m$n.sim<-m$id<-m$covariance<-m$resample.iid<-m$clusters<-m$rate.sim<-m$beta.fixed<-NULL
+  m <- match.call(expand.dots=FALSE)
+  m$robust<-m$start.time<-m$scaleLWY<-m$weighted.test<-m$beta<-m$Nit<-m$detail<-m$max.time<-m$residuals<-m$n.sim<-m$id<-m$covariance<-m$resample.iid<-m$clusters<-m$rate.sim<-m$beta.fixed<-m$max.clust <- NULL
 
   if (resample.iid==1 & robust==0) {
     cat("When robust=0 no iid representaion computed\n"); 
@@ -19,12 +19,7 @@ rate.sim=1,beta.fixed=0)
     cat("Covariance based on robust iid representation\n")
     covariance<-0;}
   if (sim==1 & robust==0) {
-    cat("When robust=0, No simulations \n"); 
-    cat("n.sim set to 0\n"); 
-    sim<-0;}
-#  if (residuals==1 & robust==0) {
-#    cat("When robust=0, no martingale residuals \n"); 
-#    residuals<-0;}
+    cat("When robust=0, No simulations \n"); cat("n.sim set to 0\n"); n.sim <- 0; sim<-0;}
   if (n.sim>0 & n.sim<50) {n.sim<-50 ; cat("Minimum 50 simulations\n");}
   if (beta.fixed==1) Nit<-1; 
 
@@ -54,15 +49,21 @@ rate.sim=1,beta.fixed=0)
   ldata<-list(start=survs$start,stop=survs$stop,
               antpers=survs$antpers,antclust=survs$antclust);
 
+      if ( (!is.null(max.clust)) )  {  
+       if (max.clust < survs$antclust) {
+       qq <- quantile(clusters, probs = seq(0, 1, by = 1/max.clust))       
+       qqc <- cut(clusters, breaks = qq, include.lowest = TRUE)    
+       clusters <- as.integer(factor(qqc, labels = 1:max.clust)) -1
+       survs$antclust <- max.clust    
+       ldata$antclust <- max.clust    
+       cluster.call <- clusters; 
+       }
+      }                                                         
+
   if (npar==FALSE) covar<-data.matrix(cbind(X,Z)) else 
   stop("Both multiplicative and additive model needed");
   Ntimes <- sum(status); 
 
-  #times<-c(start.time,time2[status==1]); times<-sort(times);
-  #if (is.null(max.time)==TRUE) maxtimes<-max(times)+0.1 else 
-  #maxtimes<-max.time; 
-  #times<-times[times<maxtimes]
-  #print(cbind(time,time2)); 
   if ((sum(beta)==0) & (beta.fixed==0)) beta<-coxph(Surv(time,time2,status)~Z)$coef; 
 
   #cat("Cox-Aalen Survival Model"); cat("\n")
@@ -123,7 +124,7 @@ ylab ="Cumulative coefficients",score=FALSE)
         sim.ci=sim.ci, robust=robust, specific.comps=specific.comps,level=level,
         start.time = start.time, stop.time = stop.time, add.to.plot=add.to.plot,
         mains=mains, xlab=xlab, ylab =ylab)
-  else plot.score(object, specific.comps=specific.comps, mains=mains,
+  else plotScore(object, specific.comps=specific.comps, mains=mains,
                   xlab=xlab,ylab =ylab);
 }
 
